@@ -27,6 +27,8 @@ class PebbleHardware(object):
     ROBERT_BB = 0xF9
     SILK_BB2 = 0xF8
     ROBERT_BB2 = 0xF7
+    SILK_FLINT = 0xF6
+    SNOWY_ROBERT = 0xF5
 
     PLATFORMS = {
         UNKNOWN: 'unknown',
@@ -53,6 +55,8 @@ class PebbleHardware(object):
         ROBERT_BB: 'emery',
         SILK_BB2: 'diorite',
         ROBERT_BB2: 'emery',
+        SILK_FLINT: 'flint',
+        SNOWY_ROBERT: 'emery',
     }
 
     @classmethod
